webview_flutter_lwe
library
Classes
-
LweNavigationDelegate
-
A place to register callback methods responsible to handle navigation events
triggered by the
LweWebView.
-
LweWebResourceError
-
Error returned in
WebView.onWebResourceError when a web resource loading error has occurred.
-
LweWebViewController
-
An implementation of
PlatformWebViewController using the Lightweight Web Engine.
-
LweWebViewCookieManager
-
Handles all cookie operations for the current platform.
-
LweWebViewPlatform
-
An implementation of
WebViewPlatform using the Lightweight Web Engine.
-
LweWebViewWidget
-
An implementation of
PlatformWebViewWidget with the Lightweight Web Engine.